import { AriaTextFieldProps } from "@react-ui-types/textfield";
import { InputHTMLAttributes, LabelHTMLAttributes, RefObject, ElementType } from "react";
interface TextFieldAria {
    /** Props for the input element. */
    inputProps: InputHTMLAttributes<HTMLInputElement & HTMLTextAreaElement>;
    /** Props for the text field's visible label element (if any). */
    labelProps: LabelHTMLAttributes<HTMLLabelElement>;
}
interface AriaTextFieldOptions extends AriaTextFieldProps {
    /**
     * The HTML element used to render the input, e.g. 'input', or 'textarea'.
     * It determines whether certain HTML attributes will be included in `inputProps`.
     * For example, [`type`](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/input#attr-type).
     * @default 'input'
     */
    inputElementType?: ElementType;
}
/**
 * Provides the behavior and accessibility implementation for a text field.
 * @param props - Props for the text field.
 * @param ref - Ref to the HTML input or textarea element.
 */
export function useTextField(props: AriaTextFieldOptions, ref: RefObject<HTMLInputElement | HTMLTextAreaElement>): TextFieldAria;

//# sourceMappingURL=types.d.ts.map
